sqltriples.Query

Module sqltriples :: Class Query |
[show private | hide private]
[frames | no frames]

## Class Query

Known Subclasses:
  `Negation`, `Results`, `SetQuery`

An abstract class providing support for lazy query evaluation.

Method Summary
| `__init__(self, store)`
| `__getitem__(self, i)`
| `__len__(self)`
| `__repr__(self)`
| ``get_child_query`(self, index)` Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query.
| `_ensure(self)`

Method Details

### get_child_query(self, index) Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query. Employ the given 'index' to correctly qualify the clause's "exposed" columns.

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net